package javax.management.remote.rmi;

import javax.management.remote.NotificationResult;
import javax.management.ListenerNotFoundException;
import javax.management.IntrospectionException;
import javax.management.MBeanInfo;
import javax.management.InvalidAttributeValueException;
import javax.management.AttributeList;
import javax.management.AttributeNotFoundException;
import java.util.Set;
import java.rmi.MarshalledObject;
import javax.management.InstanceNotFoundException;
import javax.management.NotCompliantMBeanException;
import javax.management.MBeanException;
import javax.management.MBeanRegistrationException;
import javax.management.InstanceAlreadyExistsException;
import javax.management.ReflectionException;
import javax.management.ObjectInstance;
import javax.security.auth.Subject;
import javax.management.ObjectName;
import java.io.IOException;
import java.rmi.Remote;
import java.io.Closeable;

public interface RMIConnection extends Closeable, Remote
{
    public abstract String getConnectionId() throws IOException;
    
    public abstract void close() throws IOException;
    
    public abstract ObjectInstance createMBean(String p0, ObjectName p1, Subject p2) throws ReflectionException, InstanceAlreadyExistsException, MBeanRegistrationException, MBeanException, NotCompliantMBeanException, IOException;
    
    public abstract ObjectInstance createMBean(String p0, ObjectName p1, ObjectName p2, Subject p3) throws ReflectionException, InstanceAlreadyExistsException, MBeanRegistrationException, MBeanException, NotCompliantMBeanException, InstanceNotFoundException, IOException;
    
    public abstract ObjectInstance createMBean(String p0, ObjectName p1, MarshalledObject p2, String[] p3, Subject p4) throws ReflectionException, InstanceAlreadyExistsException, MBeanRegistrationException, MBeanException, NotCompliantMBeanException, IOException;
    
    public abstract ObjectInstance createMBean(String p0, ObjectName p1, ObjectName p2, MarshalledObject p3, String[] p4, Subject p5) throws ReflectionException, InstanceAlreadyExistsException, MBeanRegistrationException, MBeanException, NotCompliantMBeanException, InstanceNotFoundException, IOException;
    
    public abstract void unregisterMBean(ObjectName p0, Subject p1) throws InstanceNotFoundException, MBeanRegistrationException, IOException;
    
    public abstract ObjectInstance getObjectInstance(ObjectName p0, Subject p1) throws InstanceNotFoundException, IOException;
    
    public abstract Set<ObjectInstance> queryMBeans(ObjectName p0, MarshalledObject p1, Subject p2) throws IOException;
    
    public abstract Set<ObjectName> queryNames(ObjectName p0, MarshalledObject p1, Subject p2) throws IOException;
    
    public abstract boolean isRegistered(ObjectName p0, Subject p1) throws IOException;
    
    public abstract Integer getMBeanCount(Subject p0) throws IOException;
    
    public abstract Object getAttribute(ObjectName p0, String p1, Subject p2) throws MBeanException, AttributeNotFoundException, InstanceNotFoundException, ReflectionException, IOException;
    
    public abstract AttributeList getAttributes(ObjectName p0, String[] p1, Subject p2) throws InstanceNotFoundException, ReflectionException, IOException;
    
    public abstract void setAttribute(ObjectName p0, MarshalledObject p1, Subject p2) throws InstanceNotFoundException, AttributeNotFoundException, InvalidAttributeValueException, MBeanException, ReflectionException, IOException;
    
    public abstract AttributeList setAttributes(ObjectName p0, MarshalledObject p1, Subject p2) throws InstanceNotFoundException, ReflectionException, IOException;
    
    public abstract Object invoke(ObjectName p0, String p1, MarshalledObject p2, String[] p3, Subject p4) throws InstanceNotFoundException, MBeanException, ReflectionException, IOException;
    
    public abstract String getDefaultDomain(Subject p0) throws IOException;
    
    public abstract String[] getDomains(Subject p0) throws IOException;
    
    public abstract MBeanInfo getMBeanInfo(ObjectName p0, Subject p1) throws InstanceNotFoundException, IntrospectionException, ReflectionException, IOException;
    
    public abstract boolean isInstanceOf(ObjectName p0, String p1, Subject p2) throws InstanceNotFoundException, IOException;
    
    public abstract void addNotificationListener(ObjectName p0, ObjectName p1, MarshalledObject p2, MarshalledObject p3, Subject p4) throws InstanceNotFoundException, IOException;
    
    public abstract void removeNotificationListener(ObjectName p0, ObjectName p1, Subject p2) throws InstanceNotFoundException, ListenerNotFoundException, IOException;
    
    public abstract void removeNotificationListener(ObjectName p0, ObjectName p1, MarshalledObject p2, MarshalledObject p3, Subject p4) throws InstanceNotFoundException, ListenerNotFoundException, IOException;
    
    public abstract Integer[] addNotificationListeners(ObjectName[] p0, MarshalledObject[] p1, Subject[] p2) throws InstanceNotFoundException, IOException;
    
    public abstract void removeNotificationListeners(ObjectName p0, Integer[] p1, Subject p2) throws InstanceNotFoundException, ListenerNotFoundException, IOException;
    
    public abstract NotificationResult fetchNotifications(long p0, int p1, long p2) throws IOException;
}
